==> qtjambi-qt3drender-5.15.8-sources.jar: io/qt/qt3d/render/QTechniqueFilter.java <==
package io.qt.qt3d.render;


/**
 * <p>A QFrameGraphNode used to select QTechniques to use</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html">Qt3DRender::QTechniqueFilter</a></p>
 */
public class QTechniqueFilter extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTechniqueFilter.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTechniqueFilter(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTechniqueFilter() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#QTechniqueFilter">Qt3DRender::QTechniqueFilter::QTechniqueFilter(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTechniqueFilter(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTechniqueFilter instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#addMatch">Qt3DRender::QTechniqueFilter::addMatch(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addMatch(io.qt.qt3d.render.QFilterKey filterKey){
        addMatch_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void addMatch_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#addParameter">Qt3DRender::QTechniqueFilter::addParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addParameter(io.qt.qt3d.render.QParameter p){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#matchAll">Qt3DRender::QTechniqueFilter::matchAll()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QFilterKey> matchAll(){
        return matchAll_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QFilterKey> matchAll_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#parameters">Qt3DRender::QTechniqueFilter::parameters()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#removeMatch">Qt3DRender::QTechniqueFilter::removeMatch(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeMatch(io.qt.qt3d.render.QFilterKey filterKey){
        removeMatch_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void removeMatch_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#removeParameter">Qt3DRender::QTechniqueFilter::removeParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.QParameter p){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTechniqueFilter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTechniqueFilter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTechniqueFilter instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-5.15.10-sources.jar: io/qt/qt3d/render/QTechniqueFilter.java <==
package io.qt.qt3d.render;


/**
 * <p>A QFrameGraphNode used to select QTechniques to use</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html">Qt3DRender::QTechniqueFilter</a></p>
 */
public class QTechniqueFilter extends io.qt.qt3d.render.QFrameGraphNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTechniqueFilter.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTechniqueFilter(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTechniqueFilter() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#QTechniqueFilter">Qt3DRender::QTechniqueFilter::QTechniqueFilter(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTechniqueFilter(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTechniqueFilter instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#addMatch">Qt3DRender::QTechniqueFilter::addMatch(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addMatch(io.qt.qt3d.render.QFilterKey filterKey){
        addMatch_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void addMatch_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#addParameter">Qt3DRender::QTechniqueFilter::addParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addParameter(io.qt.qt3d.render.QParameter p){
        addParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void addParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qnode-obsolete.html#createNodeCreationChange">Qt3DCore::QNode::createNodeCreationChange()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange() throws io.qt.QNoImplementationException {
        return createNodeCreationChange_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    private static io.qt.qt3d.core.QNodeCreatedChange createNodeCreationChange_native_constfct(long __this__nativeId) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#matchAll">Qt3DRender::QTechniqueFilter::matchAll()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QFilterKey> matchAll(){
        return matchAll_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QFilterKey> matchAll_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#parameters">Qt3DRender::QTechniqueFilter::parameters()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters(){
        return parameters_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.render.QParameter> parameters_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#removeMatch">Qt3DRender::QTechniqueFilter::removeMatch(Qt3DRender::QFilterKey*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeMatch(io.qt.qt3d.render.QFilterKey filterKey){
        removeMatch_native_Qt3DRender_QFilterKey_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(filterKey));
    }
    
    @io.qt.QtUninvokable
    private native void removeMatch_native_Qt3DRender_QFilterKey_ptr(long __this__nativeId, long filterKey);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtechniquefilter.html#removeParameter">Qt3DRender::QTechniqueFilter::removeParameter(Qt3DRender::QParameter*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeParameter(io.qt.qt3d.render.QParameter p){
        removeParameter_native_Qt3DRender_QParameter_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(p));
    }
    
    @io.qt.QtUninvokable
    private native void removeParameter_native_Qt3DRender_QParameter_ptr(long __this__nativeId, long p);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTechniqueFilter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTechniqueFilter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTechniqueFilter instance, QDeclarativeConstructor constructor);
    
}
